==> PCI8102_210.zip: Dos/sample1.c <==
/*============================================================================
//	aPCI8102 Tv\tgP
//
//	Copyright ADTEK SYSTEM SCIENCE Co.,Ltd.
//
//  TvF
//		aPCIײނ̻޽ٰ݂̱ڽ擾āAaPCI8102̐ڑ󋵂\܂
//
//	@@EPCI BIOSްޮ
//	@@EPnPײންޮ
//	@@E޲ ID
//	@@Eذ ް ڽ
//	@@EI/O ް ڽ
//
//		uAPCICTRL.CvƁuSAMPLE1.CvRpC^NĂgpB
//
//	߲ٕ@F
//		TC++4.0̏ꍇ	tcc -ml sample1.c apcictrl.c
//		MS-C6.0̏ꍇ	cl /AL sample1.c apcictrl.c
//
//	ӁF
//	@{vOTC++4.0/MS-C6.0œmFsĂ܂B
//	̑RpCgp̏ꍇ̓TvvȌCKvɂȂꍇ
//	L܂B
//	@{vO͂lr|cnrœ\Ȏst@C𐶐łRpC
//	ł̂݃RpC\łB
//
//	{{[h͂`ohbQP𓋍ڂĂ܂
//	{{[h͊荞݂T|[gĂ܂
//
//==========================================================================*/
#include <stdio.h>
#include <stdlib.h>
#include <conio.h>
#include <dos.h>
#include "typedef.h"
#include "apci8102.h"

/*============================================================================
//		ްޮݔԍ𕶎ɕϊ
//		buff	ϊ߰ޯ̧ւ߲
//			ver		ϊްޮݔԍ
//==========================================================================*/
void GetVersionStr( char *buff, ushort ver )
{
	buff[0] = ( char )( ( ver >> 12 ) + '0' );
	if ( buff[0] == '0' )
		buff[0] = ' ';
	buff[1] = ( char )( ( ( ver >> 8 ) & 0xf ) + '0' );
	buff[2] = '.';
	buff[3] = ( char )( ( ( ver >> 4 ) & 0xf ) + '0' );
	buff[4] = ( char )( ( ver & 0xf ) + '0' );
	buff[5] = '\0';
}
/*============================================================================
//		ײނ̏ʕ\
//	߂l	PCI BIOS  1 Ԃ
//			װȂ0Ԃ
//==========================================================================*/
ushort DispDriverVersion( void )
{
APCI_VER_RES	rsp;
char			szBuff[20];
ushort			result = 0;

											/* ײނ̏Ԏ擾 */
	if ( CMD_COMPLETE == ApciGetVersion( ( LPAPCI_VER_RES )&rsp ) ) {
		if ( rsp.wPciBiosVersion != 0 ) {	/* PCI BIOSL */
											/* PCI BIOSްޮ݂\ */
			GetVersionStr( szBuff, rsp.wPciBiosVersion );
			printf( "PCI BIOS ްޮ  %s\n", szBuff );
			result = 1;
		}
											/* PnPײންޮ݂\ */
		GetVersionStr( szBuff, rsp.wDriverVersion );
		printf( "aPCI ײް ްޮ %s\n", szBuff );
	}
	return result;
}
/*============================================================================
//		PnPpޯ̧ rsp ײނ擾޲Ă
//		wNum	_ۯĐ
//	߂l	޲TRUEԂ
//==========================================================================*/
boolean dispPciInfo( ushort wNum )
{
ushort				i;
APCI_FIND_RES		rsp;
ushort				retcode;

	for ( i = 0; i < wNum; i++ ) {
												/* ޲擾 */
		retcode = ApciGetDeviceInfo( ( LPAPCI_FIND_RES )&rsp, APCI8102_BOARD_ID, i );
		if ( retcode == CMD_COMPLETE ) {		/* 擾ł */
			printf( "\n_ۯĔԍ    = %d\n", i);
			printf( "޲ ID       = %04x\n", rsp.wDeviceID );
			if ( rsp.wNumMemWindows > 0 ) {
				printf( "ذ ް ڽ = %08lx\n", rsp.dMemBase );
			}
			if ( rsp.wNumIOPort > 0 ) {
				printf( "I/O ް ڽ  = %04x\n", rsp.wIOPortBase );
			}
		}
		else									/* 擾łȂ */
			break;								/* I */
	}
	return ( i == 0 )?FALSE:TRUE;
}
/*============================================================================
//		aPCI8102S޲̏\
//==========================================================================*/
void main(void)
{
ushort	wNum;

	if ( ApciGetDriverFunc() != -1 ) {				/* ذ擾 */
		if ( ( wNum = DispDriverVersion() ) > 0 ) {	/* ײްޮݕ\ */
			dispPciInfo( APCI8102_MAX_SLOTS );		/* PnP\ */
		}
		else if ( wNum == 0 ) {
			printf( "޲܂\n" );
		}
	}
	else {
		printf( "ײނ̴ذ擾ł܂ł\n" );
	}
}


==> PCI8806_210.zip: Dos/sample1.c <==
/*============================================================================
//	aPCI8806 ٿĂP
//
//  Copyright ADTEK SYSTEM SCIENCE Co.,Ltd.
//
//  TvF
//      aPCIײނ̻޽ٰ݂̱ڽ擾āAaPCI-8806̏\܂
//
//	@@EPCI BIOSްޮ
//	@@EPnPײންޮ
//	@@E޲ ID
//	@@Eذ ް ڽ
//	@@Eذ ީ 
//	@@EI/O ް ڽ
//	@@EI/O ީ 
//	@@EIRQԍ
//
//		uAPCICTRL.CvƁuSAMPLE1.Cv߲/ݸĂgpB
//
//	߲ٕ@F
//		TC++4.0̏ꍇ	tcc -ml sample1.c apcictrl.c
//		MS-C6.0̏ꍇ	cl /AL sample1.c apcictrl.c
//
//	ӁF
//	@{۸тTC++4.0/MS-C6.0œmFsĂ܂B
//	ׂ߲̑gp̏ꍇͻ۸т̏CKvɂȂꍇ
//	L܂B
//	@{۸тMS-DOSœ\Ȏşق𐶐ł߲
//	ł̂ݺ߲ى\łB
//
//==========================================================================*/
#include <stdio.h>
#include <stdlib.h>
#include "typedef.h"
#include "apci8806.h"

/*============================================================================
//		ްޮݔԍ𕶎ɕϊ
//		buff	ϊ߰ޯ̧ւ߲
//			ver		ϊްޮݔԍ
//==========================================================================*/
void GetVersionStr( char *buff, ushort ver )
{
	buff[0] = ( char )( ver >> 12 ) + '0';
	if ( buff[0] == '0' )
		buff[0] = ' ';
	buff[1] = ( char )( ( ver >> 8 ) & 0xf ) + '0';
	buff[2] = '.';
	buff[3] = ( char )( ( ver >> 4 ) & 0xf ) + '0';
	buff[4] = ( char )( ver & 0xf ) + '0';
	buff[5] = '\0';
}
/*============================================================================
//		ײނ̏ʕ\
//	߂l	PCI BIOS  1 Ԃ
//			װȂ0Ԃ
//==========================================================================*/
ushort DispDriverVersion( void )
{
APCI_VER_RES	rsp;
char			szBuff[20];
ushort			result = 0;

											/* ײނ̏Ԏ擾 */
	if ( CMD_COMPLETE == ApciGetVersion( ( LPAPCI_VER_RES )&rsp ) ) {
		if ( rsp.wPciBiosVersion != 0 ) {	/* PCI BIOSL */
											/* PCI BIOSްޮ݂\ */
			GetVersionStr( szBuff, rsp.wPciBiosVersion );
			printf( "PCI BIOS ްޮ  %s\n", szBuff );
			result = 1;
		}
											/* PnPײންޮ݂\ */
		GetVersionStr( szBuff, rsp.wDriverVersion );
		printf( "aPCI ײް ްޮ %s\n", szBuff );
	}
	return result;
}
/*============================================================================
//		PnPpޯ̧ gaPnP_rec ײނ擾޲Ă
//	߂l	޲TRUEԂ
//==========================================================================*/
boolean dispPciInfo( ushort wNum )
{
ushort			i;
APCI_FIND_RES	rsp;
ushort			retcode;

	for ( i = 0; i < wNum; i++ ) {
												/* ޲擾 */
		retcode = ApciGetDeviceInfo( ( LPAPCI_FIND_RES )&rsp , APCI8806_BOARD_ID, i );
		if ( retcode == CMD_COMPLETE ) {		/* 擾ł */
			printf( "\n_ۯĔԍ    = %d\n", i);
			printf( "޲ ID       = %04x\n", rsp.wDeviceID );
			if ( rsp.wNumMemWindows > 0 ) {
				printf( "ذ ް ڽ = %08lx\n", rsp.dMemBase );
				printf( "ذ ީ   = %08lx\n", rsp.dMemLength );
			}
			if ( rsp.wNumIOPort > 0 ) {
				printf( "I/O ް ڽ  = %04x\n", rsp.wIOPortBase );
				printf( "I/O ީ    = %04x\n", rsp.wIOPortLength );
			}
			if ( rsp.wNumIRQs > 0 )
				printf( "IRQԍ         = %d\n", rsp.bIRQRegisters );
		}
		else									/* 擾łȂ */
			break;								/* I */
	}
	return ( i == 0 )?FALSE:TRUE;
}
/*============================================================================
//		aPCI8806S޲̏\
//==========================================================================*/
void main(void)
{
ushort	wNum;

	if ( ApciGetDriverFunc() != -1 ) {				/* ذ擾 */
		if ( ( wNum = DispDriverVersion() ) > 0 ) {	/* ײްޮݕ\ */
			dispPciInfo( APCI8806_MAX_SLOTS );		/* PnP\ */
		}
		else if ( wNum == 0 ) {
			printf( "޲܂\n" );
		}
	}
	else {
		printf( "ײނ̴ذ擾ł܂ł\n" );
	}
}
